@@ -102,3 +102,41 @@ def test_registered_attrs():
     attr_str = str(a.soar.Product)
     # Check that at least one attr value is registered
     assert 'epd_ept_asun_burst_ele_close' in attr_str
+
+
+def test_registered_instr_attrs():
+    # Check if the Solo instruments are registered in a.Instrument
+    instr_attr = a.Instrument
+    assert "SOAR" in instr_attr._attr_registry[instr_attr].client
+    assert "stix" in instr_attr._attr_registry[instr_attr].name
+
+
+def test_when_soar_provider_passed():
+    # Tests when a.Provider.soar is passed that only SOARClient results are returned
+    id = a.Instrument('EUI')
+    time = a.Time('2022-04-01 00:00', '2022-04-01 01:00')
+    provider = a.Provider.soar
+    res = Fido.search(time & id & provider)
+    assert len(res) == 1
+    assert "soar" in res.keys()
+
+
+def test_when_sdac_provider_passed():
+    # tests that only VSO EUI results are returned when explicitly setting the provider to SDAC
+    id = a.Instrument('EUI')
+    time = a.Time('2022-04-01 00:00', '2022-04-01 01:00')
+    provider = a.Provider.sdac
+    res = Fido.search(time & id & provider)
+    assert len(res) == 1
+    assert "vso" in res.keys()
+
+
+def test_when_wrong_provider_passed():
+    # Tests that no results are returned when a provider is passed which does not provide EUI data.
+    # This is different from the above test because the SDAC and the SOAR both provide EUI data while
+    # NOAA has no overlap with the data provided by the SOAR.
+    id = a.Instrument('EUI')
+    time = a.Time('2022-04-01 00:00', '2022-04-01 01:00')
+    provider = a.Provider.noaa
+    res = Fido.search(time & id & provider)
+    assert len(res) == 0
