@@ -13,7 +13,7 @@ def get_cdf_descriptors():
     res = job.get_results()
     descriptors = {}
     for row in res:
-        desc = row['cdf_descriptor'].split('>')[0].upper()
+        desc = row['logical_source'].split('_')[-1].upper()
         descriptors[desc] = row['logical_source_description']
     return descriptors
 
@@ -38,8 +38,30 @@ def get_all_descriptors():
     return desc
 
 
+def get_all_instruments():
+    # Get the unique instrument names
+    SOAR = TapPlus(url="http://soar.esac.esa.int/soar-sl-tap/tap")
+    job = SOAR.launch_job('select * from soar.instrument')
+    res = job.get_results()
+
+    instruments = ['EPD', 'EUI', 'MAG', 'METIS', 'PHI', 'RPW',
+                   'SOLOHI', 'SPICE', 'STIX', 'SWA']
+    instr_desc = {}
+    for r in res:
+        if r["name"] not in instruments:
+            pass
+        else:
+            instr_desc[r["name"]] = r["long_name"]
+    return instr_desc
+
+
 if __name__ == '__main__':
     attr_file = pathlib.Path(__file__).parent.parent / 'sunpy_soar' / 'data' / 'attrs.json'
     descriptors = get_all_descriptors()
     with open(attr_file, 'w') as attrs_file:
         json.dump(dict(sorted(descriptors.items())), attrs_file, indent=2)
+
+    instr_file = pathlib.Path(__file__).parent.parent / 'sunpy_soar' / 'data' / 'instrument_attrs.json'
+    instr_descriptors = get_all_instruments()
+    with open(instr_file, 'w') as instrs_file:
+        json.dump(dict(sorted(instr_descriptors.items())), instrs_file, indent=2)
